/* The GIMP -- an image manipulation program
 * Copyright (C) 1995-1997 Spencer Kimball and Peter Mattis
 *
 * GIMP Plug-in for Texas Instruments Pictures files.
 * Copyright (C) 2002 Romain Lievin <roms@lpg.ticalc.org>
 * Some parts from Christian Kreibich's WinIcon plugin <christian@whoop.org>.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __MAIN_H__
#define __MAIN_H__

#include "config.h"

#include <stdio.h>
#include <libgimp/gimp.h>

#include <tilp/tifiles.h>
#include <tilp/macros.h>

extern gboolean   interactive_pic;

#ifdef PIC_DBG
#define D(x) \
{ \
  printf("PIC plugin: "); \
  printf x; \
}
#else
#define D(x)
#endif


#define SWAP32(x) \
((((x) & 0x000000ff ) << 24) |\
 (((x) & 0x0000ff00 ) << 8) |\
 (((x) & 0x00ff0000 ) >> 8) |\
 (((x) & 0xff000000 ) >> 24))

#define SWAP16(x) \
((((x) & 0x00ff ) << 8) |\
 (((x) & 0xff00 ) >> 8))

#ifdef WORDS_BIGENDIAN

#define ENDIAN_SWAP32(x) (SWAP32(x))
#define ENDIAN_SWAP16(x) (SWAP16(x))

#define A_VAL(p) ((guchar *)(p))[0]
#define R_VAL(p) ((guchar *)(p))[1]
#define G_VAL(p) ((guchar *)(p))[2]
#define B_VAL(p) ((guchar *)(p))[3]

#else

#define ENDIAN_SWAP32(x) (x)
#define ENDIAN_SWAP16(x) (x)

#define A_VAL(p) ((guchar *)(p))[3]
#define R_VAL(p) ((guchar *)(p))[2]
#define G_VAL(p) ((guchar *)(p))[1]
#define B_VAL(p) ((guchar *)(p))[0]

#endif

#define MAXLEN 4096


typedef struct _TiPicture
{
  char         *filename;
  FILE         *fp;

  TiRegular    *content;
  TiVarEntry   *entry;

  guint32       nbytes;
  guint32       width;
  guint32       height;
  guint8       *bitmap;
  guint8        offset;
} TiPicture;

void
pic_cleanup(TiPicture *pic);

extern gint pic_size[TIFILES_NCALCS+1][2];

#endif
